

/* DateTime2 Precision in action */
DECLARE @now datetime2(7) 
SET @now = '2009-03-17 17:19:22.2517405'

SELECT @now [7]
SELECT CAST(@now as datetime2(6)) [6]
SELECT CAST(@now as datetime2(5)) [5]
SELECT CAST(@now as datetime2(4)) [4]
SELECT CAST(@now as datetime2(3)) [3]
SELECT CAST(@now as datetime2(2)) [2]
SELECT CAST(@now as datetime2(1)) [1]


/* magic numbers: */
USE AdventureWorks
GO

-- note that times are missing from the following:
SELECT BirthDate FROM HumanResources.Employee

-- note that dates are 'missing' from these results:
SELECT StartTime, EndTime FROM HumanResources.Shift

-- SARGable arguments:
DECLARE @40yearsAgo date = DATEADD(yy, -40, GETDATE())
SELECT @40yearsAgo

SELECT * FROM HumanResources.Employee
WHERE BirthDate < @40yearsAgo


/*  populating and working with new date/time data types: */
SELECT
  CAST('2009-09-09' as date)[date],
  CAST('02:22:22' as time(0))[time(0)],
  CAST('02:22:22.22222222' as time(7))[time(7)],
  CAST('2009-09-09 02:22:22.2222222' as datetime2(7))[datetime2(7)],
  CAST('2009-09-09 02:22:22.22 +02:30' as datetimeoffset(2)) [datetimeoffset]
	
DECLARE @date date = '2009-09-09'
DECLARE @time time(7) = '02:22:22.2222222'
DECLARE @datetime2 datetime2(7) = '2009-09-09 02:22:22.222222'
DECLARE	@datetimeoffset datetimeoffset(2) = '2009-09-09 02:22:22.22 +02:30'

SELECT 
	@date [date],
	@time [time(7)],
	CAST(@datetime2 as datetime2(3)) [truncated],
	@datetimeoffset [offset]


/* dynamic population using system functions: */
-- old functions (less precise)
SELECT 
	GETDATE() [GetDate()],
	GETUTCDATE() [GetUTCDate()]
	
-- new fuctions (much more precise)
SELECT
	SYSDATETIME() [SysDateTime()],
	SYSUTCDATETIME() [SysUTCDateTime()],
	SYSDATETIMEOFFSET() [SysDateTimeOffset()]


/* casting and converting */
-- casting datetime to date
DECLARE @date date = GETDATE()

-- casting datetime to time
DECLARE @time time = GETDATE()

SELECT
	@date [date],
	@time [time], -- note default precision
	CAST(@time as time(2)) [converted]








